@@ -33,6 +33,7 @@ import android.os.Build;
 import android.os.Bundle;
 import android.os.Handler;
 import android.os.Message;
+import android.support.annotation.MainThread;
 import android.support.v17.leanback.app.BackgroundManager;
 import android.support.v17.leanback.app.BrowseFragment;
 import android.support.v17.leanback.app.BrowseSupportFragment;
@@ -56,12 +57,14 @@ import android.widget.ProgressBar;
 
 import org.videolan.libvlc.Media;
 import org.videolan.libvlc.MediaPlayer;
+import org.videolan.libvlc.util.AndroidUtil;
 import org.videolan.medialibrary.Medialibrary;
 import org.videolan.medialibrary.Tools;
 import org.videolan.medialibrary.interfaces.MediaUpdatedCb;
 import org.videolan.medialibrary.media.MediaWrapper;
 import org.videolan.vlc.BuildConfig;
 import org.videolan.vlc.ExternalMonitor;
+import org.videolan.vlc.MediaParsingService;
 import org.videolan.vlc.PlaybackService;
 import org.videolan.vlc.R;
 import org.videolan.vlc.RecommendationsService;
@@ -77,10 +80,10 @@ import org.videolan.vlc.gui.tv.browser.VerticalGridActivity;
 import org.videolan.vlc.media.MediaDatabase;
 import org.videolan.vlc.media.MediaUtils;
 import org.videolan.vlc.util.AndroidDevices;
+import org.videolan.vlc.util.Constants;
 import org.videolan.vlc.util.Permissions;
 import org.videolan.vlc.util.VLCInstance;
 
-import java.util.ArrayList;
 import java.util.List;
 
 @TargetApi(Build.VERSION_CODES.JELLY_BEAN_MR1)
@@ -166,6 +169,7 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
     public void onConnected(PlaybackService service) {
         super.onConnected(service);
         mService.addCallback(this);
+        if (!mMediaLibrary.isInitiated()) return;
         /*
          * skip browser and show directly Audio Player if a song is playing
          */
@@ -193,46 +197,37 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
 
     @Override
     public void onDisconnected() {
-        if (mService != null)
-            mService.removeCallback(this);
+        if (mService != null) mService.removeCallback(this);
         super.onDisconnected();
     }
 
     @Override
     protected void onStart() {
         super.onStart();
-        if (!mBackgroundManager.isAttached())
-            mBackgroundManager.attach(getWindow());
-        if (mSelectedItem != null)
-            TvUtil.updateBackground(mBackgroundManager, mSelectedItem);
+        if (!mBackgroundManager.isAttached()) mBackgroundManager.attach(getWindow());
+        if (mSelectedItem != null) TvUtil.updateBackground(mBackgroundManager, mSelectedItem);
     }
 
     @Override
     protected void onStop() {
         super.onStop();
-        if (AndroidDevices.isAndroidTv)
-            startService(new Intent(this, RecommendationsService.class));
+        if (AndroidDevices.isAndroidTv && !AndroidUtil.isOOrLater) startService(new Intent(this, RecommendationsService.class));
         TvUtil.releaseBackgroundManager(mBackgroundManager);
     }
 
     @Override
     protected void onResume() {
         super.onResume();
-        if (mService != null)
-            mService.addCallback(this);
-        if (mMediaLibrary.isInitiated())
-            setmedialibraryListeners();
-        else
-            setupMediaLibraryReceiver();
+        if (mService != null) mService.addCallback(this);
+        if (mMediaLibrary.isInitiated()) setmedialibraryListeners();
+        else setupMediaLibraryReceiver();
     }
 
     @Override
     protected void onPause() {
-        if (mUpdateTask != null)
-            mUpdateTask.cancel(true);
+        if (mUpdateTask != null) mUpdateTask.cancel(true);
         super.onPause();
-        if (mService != null)
-            mService.removeCallback(this);
+        if (mService != null) mService.removeCallback(this);
         mMediaLibrary.removeMediaUpdatedCb();
     }
 
@@ -242,8 +237,7 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
         if (requestCode == ACTIVITY_RESULT_PREFERENCES) {
             switch (resultCode) {
                 case PreferencesActivity.RESULT_RESCAN:
-                    VLCApplication.getMLInstance().reload();
-                    update();
+                    startService(new Intent(Constants.ACTION_RELOAD, null,this, MediaParsingService.class));;
                     break;
                 case PreferencesActivity.RESULT_RESTART:
                 case PreferencesActivity.RESULT_RESTART_APP:
@@ -258,12 +252,11 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
 
     @Override
     public boolean onKeyDown(int keyCode, KeyEvent event) {
-        if ((keyCode == KeyEvent.KEYCODE_MEDIA_PLAY_PAUSE || keyCode == KeyEvent.KEYCODE_BUTTON_Y) && mSelectedItem instanceof MediaWrapper) {
+        if ((keyCode == KeyEvent.KEYCODE_MEDIA_PLAY_PAUSE || keyCode == KeyEvent.KEYCODE_BUTTON_Y)
+                && mSelectedItem instanceof MediaWrapper) {
             MediaWrapper media = (MediaWrapper) mSelectedItem;
-            if (media.getType() != MediaWrapper.TYPE_DIR)
-                return false;
-            final Intent intent = new Intent(this,
-                    DetailsActivity.class);
+            if (media.getType() != MediaWrapper.TYPE_DIR) return false;
+            final Intent intent = new Intent(this, DetailsActivity.class);
             // pass the item information
             intent.putExtra("media", (MediaWrapper) mSelectedItem);
             intent.putExtra("item", new MediaItemDetails(media.getTitle(), media.getArtist(), media.getAlbum(), media.getLocation(), media.getArtworkURL()));
@@ -282,20 +275,17 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
 
     @Override
     public void onMediaUpdated(final MediaWrapper[] mediaList) {
-        if (mVideoAdapter == null || mVideoAdapter.size() > NUM_ITEMS_PREVIEW)
-            return;
+        if (mVideoAdapter == null || mVideoAdapter.size() > NUM_ITEMS_PREVIEW) return;
         mHandler.post(new Runnable() {
             @Override
             public void run() {
-                for (MediaWrapper media : mediaList)
-                    updateItem(media);
+                for (MediaWrapper media : mediaList) updateItem(media);
             }
         });
     }
 
     public void updateItem(MediaWrapper item) {
-        if (item == null)
-            return;
+        if (item == null) return;
         if (mVideoAdapter != null) {
             if (mVideoIndex.containsKey(item.getLocation())) {
                 mVideoAdapter.notifyArrayItemRangeChanged(mVideoIndex.get(item.getLocation()), 1);
@@ -326,28 +316,22 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
                 startActivity(new Intent(this, AudioPlayerActivity.class));
                 return;
             }
-            CardPresenter.SimpleCard card = (CardPresenter.SimpleCard) item;
-            Intent intent = new Intent(mContext, VerticalGridActivity.class);
+            final CardPresenter.SimpleCard card = (CardPresenter.SimpleCard) item;
+            final Intent intent = new Intent(mContext, VerticalGridActivity.class);
             intent.putExtra(BROWSER_TYPE, HEADER_CATEGORIES);
             intent.putExtra(MusicFragment.AUDIO_CATEGORY, card.getId());
             startActivity(intent);
         } else if (row.getId() == HEADER_MISC) {
             long id = ((CardPresenter.SimpleCard) item).getId();
-            if (id == ID_SETTINGS)
-                startActivityForResult(new Intent(this, org.videolan.vlc.gui.tv.preferences.PreferencesActivity.class), ACTIVITY_RESULT_PREFERENCES);
-            else if (id == ID_ABOUT)
-                startActivity(new Intent(this, org.videolan.vlc.gui.tv.AboutActivity.class));
-            else if (id == ID_LICENCE)
-                startActivity(new Intent(this, org.videolan.vlc.gui.tv.LicenceActivity.class));
-        } else {
-            TvUtil.openMedia(mContext, item, row);
-        }
+            if (id == ID_SETTINGS) startActivityForResult(new Intent(this, org.videolan.vlc.gui.tv.preferences.PreferencesActivity.class), ACTIVITY_RESULT_PREFERENCES);
+            else if (id == ID_ABOUT) startActivity(new Intent(this, org.videolan.vlc.gui.tv.AboutActivity.class));
+            else if (id == ID_LICENCE) startActivity(new Intent(this, org.videolan.vlc.gui.tv.LicenceActivity.class));
+        } else TvUtil.openMedia(mContext, item, row);
     }
 
     @Override
     public void onClick(View v) {
-        Intent intent = new Intent(mContext, SearchActivity.class);
-        startActivity(intent);
+        startActivity(new Intent(mContext, SearchActivity.class));
     }
 
     @Override
@@ -357,8 +341,7 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
 
     @Override
     protected void onParsingServiceProgress() {
-        if (mProgressBar.getVisibility() == View.GONE)
-            mHandler.sendEmptyMessage(SHOW_LOADING);
+        if (mProgressBar.getVisibility() == View.GONE) mHandler.sendEmptyMessage(SHOW_LOADING);
     }
 
     @Override
@@ -398,11 +381,9 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
 
         @Override
         protected Void doInBackground(Void... params) {
-            if (isCancelled())
-                return null;
+            if (isCancelled()) return null;
             videoList = mMediaLibrary.getRecentVideos();
-            if (showHistory && !isCancelled())
-                history = VLCApplication.getMLInstance().lastMediaPlayed();
+            if (showHistory && !isCancelled()) history = VLCApplication.getMLInstance().lastMediaPlayed();
             return null;
         }
 
@@ -414,17 +395,13 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
         @Override
         protected void onPostExecute(Void result) {
             mHandler.sendEmptyMessage(HIDE_LOADING);
-            if (!isVisible())
-                return;
-            if (mRowsAdapter != null)
-                mRowsAdapter.clear();
-            else
-                mRowsAdapter = new ArrayObjectAdapter(new ListRowPresenter());
+            if (!isVisible()) return;
+            if (mRowsAdapter != null) mRowsAdapter.clear();
+            else mRowsAdapter = new ArrayObjectAdapter(new ListRowPresenter());
             mHistoryIndex.clear();
             //Video Section
             mVideoIndex.clear();
-            mVideoAdapter = new ArrayObjectAdapter(
-                    new CardPresenter(mContext));
+            mVideoAdapter = new ArrayObjectAdapter(new CardPresenter(mContext));
             final HeaderItem videoHeader = new HeaderItem(HEADER_VIDEO, getString(R.string.video));
             // Empty item to launch grid activity
             mVideoAdapter.add(new CardPresenter.SimpleCard(0, "All videos", videoList.length+" "+getString(R.string.videos), R.drawable.ic_video_collection_big));
@@ -450,13 +427,7 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
             mRowsAdapter.add(new ListRow(musicHeader, mCategoriesAdapter));
 
             //History
-            if (showHistory && !Tools.isArrayEmpty(history)){
-                mHistoryAdapter = new ArrayObjectAdapter(
-                        new CardPresenter(mContext));
-                final HeaderItem historyHeader = new HeaderItem(HEADER_HISTORY, getString(R.string.history));
-                updateHistory(history);
-                mRowsAdapter.add(new ListRow(historyHeader, mHistoryAdapter));
-            }
+            if (showHistory && !Tools.isArrayEmpty(history)) updateHistory(history);
 
             //Browser section
             mBrowserAdapter = new ArrayObjectAdapter(new CardPresenter(mContext));
@@ -481,33 +452,35 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
         }
     }
 
+    @MainThread
     private void updateHistory(MediaWrapper[] history) {
-        if (mHistoryAdapter == null || history == null)
-            return;
-        mHistoryAdapter.clear();
-        if (!mSettings.getBoolean(PreferencesFragment.PLAYBACK_HISTORY, true))
-            return;
-        MediaWrapper item;
+        if (history == null) return;
+        final boolean createAdapter = mHistoryAdapter == null;
+        if (createAdapter) mHistoryAdapter = new ArrayObjectAdapter(new CardPresenter(mContext));
+        else mHistoryAdapter.clear();
+        if (!mSettings.getBoolean(PreferencesFragment.PLAYBACK_HISTORY, true)) return;
         for (int i = 0; i < history.length; ++i) {
-            item = history[i];
+            final MediaWrapper item = history[i];
             mHistoryAdapter.add(item);
             mHistoryIndex.put(item.getLocation(), i);
         }
+        if (createAdapter) {
+            final HeaderItem historyHeader = new HeaderItem(HEADER_HISTORY, getString(R.string.history));
+            mRowsAdapter.add(Math.min(2, mRowsAdapter.size()), new ListRow(historyHeader, mHistoryAdapter));
+        }
     }
 
     private void updateBrowsers() {
-        if (mBrowserAdapter == null)
-            return;
+        if (mBrowserAdapter == null) return;
         mBrowserAdapter.clear();
-        List<MediaWrapper> directories = AndroidDevices.getMediaDirectoriesList();
-        if (!AndroidDevices.showInternalStorage && !directories.isEmpty())
-            directories.remove(0);
+        final List<MediaWrapper> directories = AndroidDevices.getMediaDirectoriesList();
+        if (!AndroidDevices.showInternalStorage && !directories.isEmpty()) directories.remove(0);
         for (MediaWrapper directory : directories)
             mBrowserAdapter.add(new CardPresenter.SimpleCard(HEADER_DIRECTORIES, directory.getTitle(), R.drawable.ic_menu_folder_big, directory.getUri()));
 
         if (ExternalMonitor.isLan()) {
             try {
-                final ArrayList<MediaWrapper> favs = MediaDatabase.getInstance().getAllNetworkFav();
+                final List<MediaWrapper> favs = MediaDatabase.getInstance().getAllNetworkFav();
                 mBrowserAdapter.add(new CardPresenter.SimpleCard(HEADER_NETWORK, getString(R.string.network_browsing), R.drawable.ic_menu_network_big));
                 mBrowserAdapter.add(new CardPresenter.SimpleCard(HEADER_STREAM, getString(R.string.open_mrl), R.drawable.ic_menu_stream_big));
 
@@ -553,8 +526,7 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
     }
 
     public void updateNowPlayingCard () {
-        if (mService == null)
-            return;
+        if (mService == null) return;
         final boolean hasmedia = mService.hasMedia();
         final boolean canSwitch = mService.canSwitchToVideo();
         if ((!hasmedia || canSwitch) && mNowPlayingCard != null) {
@@ -571,18 +543,14 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
                         @Override
                         public void run() {
                             if (mNowPlayingCard == null) {
-                                if (cover != null)
-                                    mNowPlayingCard = new CardPresenter.SimpleCard(MusicFragment.CATEGORY_NOW_PLAYING, display, cover);
-                                else
-                                    mNowPlayingCard = new CardPresenter.SimpleCard(MusicFragment.CATEGORY_NOW_PLAYING, display, R.drawable.ic_default_cone);
+                                if (cover != null) mNowPlayingCard = new CardPresenter.SimpleCard(MusicFragment.CATEGORY_NOW_PLAYING, display, cover);
+                                else mNowPlayingCard = new CardPresenter.SimpleCard(MusicFragment.CATEGORY_NOW_PLAYING, display, R.drawable.ic_default_cone);
                                 mCategoriesAdapter.add(0, mNowPlayingCard);
                             } else {
                                 mNowPlayingCard.setId(MusicFragment.CATEGORY_NOW_PLAYING);
                                 mNowPlayingCard.setName(display);
-                                if (cover != null)
-                                    mNowPlayingCard.setImage(cover);
-                                else
-                                    mNowPlayingCard.setImageId(R.drawable.ic_default_cone);
+                                if (cover != null) mNowPlayingCard.setImage(cover);
+                                else mNowPlayingCard.setImageId(R.drawable.ic_default_cone);
                             }
                             mCategoriesAdapter.notifyArrayItemRangeChanged(0,1);
                         }
