@@ -51,6 +51,7 @@ import org.videolan.vlc.extensions.ExtensionManagerService;
 import org.videolan.vlc.extensions.ExtensionsManager;
 import org.videolan.vlc.extensions.api.VLCExtensionItem;
 import org.videolan.vlc.gui.helpers.AudioUtil;
+import org.videolan.vlc.util.Constants;
 
 import java.util.ArrayList;
 import java.util.List;
@@ -83,12 +84,12 @@ public class BrowserProvider implements ExtensionManagerService.ExtensionManager
     // Extensions management
     private static ServiceConnection sExtensionServiceConnection = null;
     private static ExtensionManagerService sExtensionManagerService;
-    private static ArrayList<MediaBrowserCompat.MediaItem> extensionItems = new ArrayList<>();
+    private static List<MediaBrowserCompat.MediaItem> extensionItems = new ArrayList<>();
     private static Semaphore extensionLock = new Semaphore(0);
 
     @WorkerThread
     public static List<MediaBrowserCompat.MediaItem> browse(String parentId) {
-        ArrayList<MediaBrowserCompat.MediaItem> results = new ArrayList<>();
+        List<MediaBrowserCompat.MediaItem> results = new ArrayList<>();
         MediaLibraryItem[] list = null;
         boolean limitSize = false;
         Resources res = VLCApplication.getAppResources();
@@ -208,7 +209,7 @@ public class BrowserProvider implements ExtensionManagerService.ExtensionManager
                     list = VLCApplication.getMLInstance().lastMediaPlayed();
                     break;
                 case ID_ARTISTS:
-                    list = VLCApplication.getMLInstance().getArtists();
+                    list = VLCApplication.getMLInstance().getArtists(VLCApplication.getSettings().getBoolean(Constants.KEY_ARTISTS_SHOW_ALL, false));
                     break;
                 case ID_ALBUMS:
                     list = VLCApplication.getMLInstance().getAlbums();
